starcluster.threadpool.DaemonWorker

Package starcluster :: Module threadpool :: Class DaemonWorker |
[hide private]
[frames] | no frames]

# Class DaemonWorker

source code

Improved Worker that sets daemon = True by default and also handles communicating exceptions to the parent pool object by adding them to the parent pool's exception queue

Instance Methods | [hide private]
__init__(self, *args, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
run(self) Get jobs from the queue and perform them as they arrive. | source code
Inherited from `threading.Thread`: `__repr__`, `getName`, `isAlive`, `isDaemon`, `is_alive`, `join`, `setDaemon`, `setName`, `start` Inherited from `threading.Thread` (private): `_set_daemon`, `_set_ident` Inherited from `threading._Verbose` (private): `_note` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `threading.Thread`: `daemon`, `ident`, `name` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run(self) | source code
Get jobs from the queue and perform them as they arrive. Overrides: threading.Thread.run